﻿# -*- coding: utf-8 -*-

from Products.ZCTextIndex.ISplitter import ISplitter
from Products.ZCTextIndex.PipelineFactory import element_factory
from settings import *

# arguments passed to mecab
mecab_arglist = ['-a','-Owakati']

mecab_module = ''

try:
	from MeCab import Tagger
	mecab_module = 'mecab'
except:
	from MeCabLib import MeCabLib
	mecab_module = 'mecablib'

def get_mecab(adaptor_type):
	if adaptor_type == 'mecab':
		return Tagger(mecab_arglist)
	elif adaptor_type == 'mecablib':
		return MeCabLib(
			arglist = mecab_arglist,
			libpath = mecab_libpath
		)

def mojiconv(s, f, t):
	if f == t:
		return s
	else:
		return unicode(s, f, 'replace').encode(t, 'replace')

class MeCabAdaptor:
	"""
	wrapper of MeCab::Tagger or MeCabLib
	"""
	def __init__(self, mecab_adaptor_type, mecab_adaptor):
		self.set(mecab_adaptor_type, mecab_adaptor)

	def set(self, mecab_adaptor_type, mecab_adaptor):
		self.mecab_adaptor_type = mecab_adaptor_type
		self.adaptor = mecab_adaptor

	def parse(self, txt):
		txt = mojiconv(txt, text_charset, dic_charset)
		parsed = ''
		self.adaptor.lock()
		if self.mecab_adaptor_type == 'mecab':
			parsed = self.adaptor.parse(txt)
		elif self.mecab_adaptor_type == 'mecablib':
			parsed = self.adaptor.sparse_tostr(txt)
		self.adaptor.unlock()
		words = parsed.split()
		words = [mojiconv(w, dic_charset, text_charset) for w in words]
		return words

class MJSplitter:
	"""
	MJSplitter
	Mecab-based Japanese Splitter
	"""
	__implements__ = ISplitter

	mecabAdaptor = MeCabAdaptor(mecab_module, get_mecab(mecab_module))

	def process(self, text, glob=0):
		txt = ' '.join(text)
		return self.mecabAdaptor.parse(txt)

element_factory.registerFactory('Word Splitter', 'MJSplitter', MJSplitter)
